*$ CREATE ENDSCP.FOR
*COPY ENDSCP
*
*=== Endscp ===========================================================*
*
      SUBROUTINE ENDSCP ( IJ  , NTRUCK, XTRUCK, YTRUCK, ZTRUCK,
     &                    MREG, LLO   , ICALL )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 2001-2005      by    Alfredo Ferrari & Paola Sala  *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     ENergy density DiStributed - Change of Positions                 *
*                                                                      *
*     Created on   13 april 2001   by    Alfredo Ferrari & Paola Sala  *
*                                                                      *
*     Last change on 13-apr-01     by    Alfredo Ferrari               *
*                                                                      *
*     Input variables:                                                 *
*                                                                      *
*                   Ij = (generalized) particle code                   *
* X,Y,Ztruck(0:Ntruck) = particle step points                          *
*                 Mreg = region number                                 *
*                  Llo = particle generation                           *
*                Icall = call id.                                      *
*                                                                      *
*     Output variables:                                                *
*                                                                      *
* X,Y,Ztruck(0:Ntruck) = particle step points                          *
*                                                                      *
*     Useful variables (common SCOHLP):                                *
*                                                                      *
*     Energy/Star binnings/scorings (Comscw):                          *
*          ISCRNG = 1 --> Energy density  binning                      *
*          ISCRNG = 2 --> Star   density  binning                      *
*          ISCRNG = 3 --> Residual nuclei scoring                      *
*          JSCRNG = # of the binning                                   *
*                                                                      *
*     Useful variables (common SOUEVT):                                *
*                                                                      *
*          X,Y,Zsoevt(i) = position    of the i_th source particle     *
*          TX,Y,Zsoev(i) = direction   of the i_th source particle     *
*              Wtsoev(i) = weight      of the i_th source particle     *
*              Pmsoev(i) = momentum    of the i_th source particle     *
*              Tksoev(i) = kin. energy of the i_th source particle     *
*              Agsoev(i) = age         of the i_th source particle     *
*              Aksoev(i) = Kaon ampl.  of the i_th source particle     *
*              Ussoev(i) = user var.   of the i_th source particle     *
*              Ijsoev(i) = identity    of the i_th source particle     *
*              Nrsoev(i) = region      of the i_th source particle     *
*              Nlsoev(i) = lattice     of the i_th source particle     *
*                Npsoev  = number of the source particles              *
*                                                                      *
*----------------------------------------------------------------------*
*
      INCLUDE '(FLKMAT)'
      INCLUDE '(SCOHLP)'
      INCLUDE '(SOUEVT)'
*
      DIMENSION XTRUCK (0:NTRUCK), YTRUCK (0:NTRUCK), ZTRUCK (0:NTRUCK)
*
      RETURN
*=== End of subroutine Endscp =========================================*
      END

